/*  Project listview
    Chinchilla Soft Ltd
    Copyright  1995. All Rights Reserved.

    SUBSYSTEM:    listview.exe Application
    FILE:         containr.h
    AUTHOR:       Johannes Plachy


    OVERVIEW
    ========
    Class definition for of TContainer.

    TContainer is a wrapperclass for the Windows 95 Listview control,

    which can be used, like Explorer does,
      with large icons,
      with small icons,
      as listview
      or as reportview
*/


#ifndef CONTAINR_HXX
#define CONTAINR_HXX

#include <owl\control.h>
#include <commctrl.h>   // includes the common control header





// ---------------------------------------------------------------------------

class TContainer : public TControl
{

public :                                     // | LVS_SHAREIMAGELISTS

   TContainer( TWindow* parent, int id, const char far* title, int x = 0, int y = 0, int w = 0, int h = 0,
                DWORD dwListStyles = LVS_ICON , TModule* module = 0 );

   void ChangeView( DWORD dwnewStyle);

   void ShowSelectionAlways( BOOL ShowSelection = FALSE);

   inline HIMAGELIST SetImageList( HIMAGELIST himl, int iListStyle = LVSIL_NORMAL);
   inline HIMAGELIST GetImageList(int iImageList = LVSIL_NORMAL);
   // Items

   inline BOOL DeleteAllItems();
   inline BOOL DeleteContainerItem(int iItem);
   inline BOOL GetItem(LV_ITEM* pItem);
   inline int  GetItemCount();
   inline int  GetSelectedCount();
   inline DWORD GerItemSpaceing(BOOL bSmall);
   inline UINT GetItemState(int iItem, UINT mask);
   inline void GetItemText(int iItem, int iSubItem, LPSTR pszText, int MaxTextLen);
   inline int  InsertItem(const LV_ITEM* pItem);
   inline BOOL SetItem(const LV_ITEM* pItem);
   inline void SetItemCount(int iItemCount);
   inline void SetItemState(int iItem, UINT state, UINT mask);
   inline void SetItemText(int iItem, int iSubItem, LPCSTR pszText);

   inline BOOL RedrawItems(int iItemFirst, int iItemLast);
   inline BOOL Update(int iItem);
   inline UINT GetCallbackMask();
   inline BOOL SetCallbackMask(int iNewMask);

   // Columns

   inline int  InsertColumn( int iColumn, LV_COLUMN* pColumn);
   inline BOOL DeleteColumn( int iColumn);
   inline BOOL GetColumn( int iColumn, LV_COLUMN* pColumn);
   inline BOOL SetColumn( int iColumn, LV_COLUMN* pColumn);

   inline int  GetColumnWidth( int iColumn);
   inline BOOL SetColumnWidth( int iColumn, int iColumnWidth = LVSCW_AUTOSIZE	);
   inline int  GetStringWidth( LPCSTR psz);

   // Arranging, Sorting

   inline BOOL ArrangeItems( UINT uiAlignment = LVA_DEFAULT);
   inline int FindItem( int iStartIndex, LV_FINDINFO* pFindInfo);
   inline int GetNextItem( int iStartIndex, UINT flags);
   inline BOOL SortItems( PFNLVCOMPARE pfnCompare, LPARAM lParamSort);

   // Position & Scrolling

   inline BOOL EnsureVisible( int iItem, BOOL bPartialOk = FALSE);
   inline int GetCountPerPage();
   inline int GetTopIndex();
   inline BOOL GetItemPosition( int iItem, POINT* pt);
   inline BOOL GetItemRect( int iItem, RECT* rect, int code = LVIR_BOUNDS);
   inline BOOL GetOrigin( LPPOINT lpPoint);
   inline BOOL GetViewRect( RECT* pRect);
   inline int HitTest( LV_HITTESTINFO* phtti);
   inline BOOL Scroll( int dx, int dy);
   inline BOOL SetItemPosition( int iItemIndex, int x, int y);

protected:

   char* GetClassName();

private:
   inline LRESULT SendMessage(HWND HWindow, uint msg, WPARAM wParam, LPARAM lParam)
   {
      return TWindow::SendMessage( msg, wParam, lParam);
   }

};

// ---------------------------------------------------------------------------


#endif // CONTAINR_HXX
