/*  Project listview
    Chinchilla Soft Ltd
    Copyright  1995. All Rights Reserved.

    SUBSYSTEM:    listview.exe Application
    FILE:         treeview.h
    AUTHOR:       Johannes Plachy


    OVERVIEW
    ========
    Class definition for of TTreeView.

    TImageList is a wrapperclass for the Windows 95 treeview.

*/

#ifndef TREEVIEW_HXX
#define TREEVIEW_HXX

#include <owl\control.h>
#include <commctrl.h>   // includes the common control header

// ---------------------------------------------------------------------------

class TTreeView : public TControl
{

public :                                     // | LVS_SHAREIMAGELISTS

   TTreeView( TWindow* parent, int id, const char far* title, int x = 0, int y = 0, int w = 0, int h = 0,
                DWORD dwListStyles = TVS_HASLINES | TVS_HASBUTTONS | TVS_LINESATROOT ,
                TModule* module = 0 );

   inline HTREEITEM InsertItem( LPTV_INSERTSTRUCT lpis);
   inline BOOL DeleteTreeViewItem( HTREEITEM hItem);
   inline BOOL DeleteAllItems();
   inline BOOL SetItem( const TV_ITEM* pitem);

   inline HWND EditLabel( HTREEITEM hitem);
   inline BOOL EndEditLabel( BOOL fCancel);
   inline HWND GetEditControl();
   inline BOOL GetItem( TV_ITEM* pItem);
   inline HTREEITEM SelectItem( WPARAM flags, HTREEITEM hItem);
   inline HTREEITEM SelectDropTarget( HTREEITEM hItem);
   inline HTREEITEM SelectFirstVisible( HTREEITEM hItem);
   inline HIMAGELIST GetImageList( WPARAM wImage = TVSIL_NORMAL);
   inline HIMAGELIST SetImageList( HIMAGELIST hIml, WPARAM wImage = TVSIL_NORMAL);
   inline BOOL SortChildren( HTREEITEM hItem);
   inline BOOL Expand( HTREEITEM hItem, UINT flags = TVE_EXPAND);
   inline UINT GetIndent();
   inline BOOL SetIndent( WPARAM indent);
   inline BOOL EnsureVisible( HTREEITEM hItem);
   inline UINT GetCount();
   inline UINT GetVisibleCount();
   inline BOOL GetISearchString( LPSTR lpsz);
   inline BOOL GetItemRect( HTREEITEM hItem, RECT* rect, BOOL TextOnly = FALSE);
   inline HTREEITEM GetNextItem( HTREEITEM hItem, UINT flags);
   inline HTREEITEM GetChild( HTREEITEM hitem);
   inline HTREEITEM GetDropHilite();
   inline HTREEITEM GetFirstVisible();
   inline HTREEITEM GetNextSibling( HTREEITEM hitem);
   inline HTREEITEM GetNextVisible( HTREEITEM hitem);
   inline HTREEITEM GetParent( HTREEITEM hitem);
   inline HTREEITEM GetPrevSibling( HTREEITEM hitem);
   inline HTREEITEM GetPrevVisible( HTREEITEM hitem);
   inline HTREEITEM GetRoot();
   inline HTREEITEM GetSelection();
   inline HIMAGELIST CreateDragImage( HTREEITEM hItem);
   inline HTREEITEM HitTest( LPTV_HITTESTINFO lpht);

protected:
   char* GetClassName();

private:

   inline LRESULT SendMessage(HWND HWindow, uint msg, WPARAM wParam, LPARAM lParam)
   {
      return TWindow::SendMessage( msg, wParam, lParam);
   }

};

// ---------------------------------------------------------------------------

#endif // TREEVIEW_HXX
